@@ -6,4 +6,5 @@ import maps4fs.generator.component as component
 import maps4fs.generator.settings as settings
 from maps4fs.generator.game import Game
 from maps4fs.generator.map import Map
-from maps4fs.logger import Logger
+from maps4fs.generator.monitor import Logger
+from maps4fs.generator.settings import GenerationSettings, MainSettings
