@@ -81,6 +81,9 @@ class Background(MeshComponent, ImageComponent):
         self.not_resized_with_foundations_path: str = os.path.join(
             self.background_directory, "not_resized_with_foundations.png"
         )
+        self.not_resized_with_flattened_roads_path: str = os.path.join(
+            self.background_directory, "not_resized_with_flattened_roads.png"
+        )
 
         self.flatten_water_to: int | None = None
 
@@ -823,6 +826,10 @@ class Background(MeshComponent, ImageComponent):
 
         if self.map.background_settings.flatten_water:
             try:
+                # Check if there are any water pixels (255) in the water resources image.
+                if not np.any(water_resources_image == 255):
+                    self.logger.warning("No water pixels found in water resources image.")
+                    return
                 mask = water_resources_image == 255
                 flatten_to = int(np.mean(dem_image[mask]) - subtract_by)  # type: ignore
                 self.flatten_water_to = flatten_to  # type: ignore
@@ -862,13 +869,14 @@ class Background(MeshComponent, ImageComponent):
         """
         self.logger.debug("Starting line-based water generation...")
         water_polygons = self.get_infolayer_data(Parameters.BACKGROUND, Parameters.WATER)
-        self.logger.debug(
-            "Found %s water polygons in background info layer.", len(water_polygons)  # type: ignore
-        )
         if not water_polygons:
             self.logger.warning("No water polygons found in background info layer.")
             return
 
+        self.logger.debug(
+            "Found %s water polygons in background info layer.", len(water_polygons)  # type: ignore
+        )
+
         polygons: list[shapely.Polygon] = []
         for polygon_points in water_polygons:
             if not polygon_points or len(polygon_points) < 2:
@@ -1184,6 +1192,13 @@ class Background(MeshComponent, ImageComponent):
         dem_image = self.blur_by_mask(dem_image, full_mask, blur_radius=5)
         dem_image = self.blur_edges_by_mask(dem_image, full_mask)
 
+        # Save the not resized DEM with flattened roads.
+        cv2.imwrite(self.not_resized_with_flattened_roads_path, dem_image)
+        self.logger.debug(
+            "Not resized DEM with flattened roads saved to: %s",
+            self.not_resized_with_flattened_roads_path,
+        )
+
         output_size = dem_image.shape[0] + 1
         resized_dem = cv2.resize(
             dem_image, (output_size, output_size), interpolation=cv2.INTER_NEAREST
