@@ -13,6 +13,7 @@ from maps4fs.generator.component.building import Building
 from maps4fs.generator.component.config import Config
 from maps4fs.generator.component.grle import GRLE
 from maps4fs.generator.component.i3d import I3d
+from maps4fs.generator.component.road import Road
 from maps4fs.generator.component.satellite import Satellite
 from maps4fs.generator.component.texture import Texture
 
@@ -48,7 +49,7 @@ class Game:
     _mesh_processing: bool = True
 
     # Order matters! Some components depend on others.
-    components = [Satellite, Texture, Background, GRLE, I3d, Config, Building]
+    components = [Satellite, Texture, Background, GRLE, I3d, Config, Road, Building]
 
     def __init__(self, map_template_path: str | None = None):
         if map_template_path:
